@@ -39,4 +39,4 @@ def create_ds9_file(data,ra_centers,dec_centers,theta,catalog_object_ra,catalog_
     reg_list = reg_list
 
     reg_filename = output_file+'.reg'
-    write_ds9(reg_list, reg_filename,radunit='deg')
+    write_ds9(reg_list, reg_filename,radunit='deg',overwrite=True)
